<?php
// Own namespace
namespace Org\Mxchange\City\Daemon\Filter\Bootstrap;

// Import application-specific stuff
use Org\Mxchange\City\Daemon\Factory\CityDaemonFactory;
use Org\Mxchange\City\Filter\BaseCityFilter;

// Import framework stuff
use Org\Mxchange\CoreFramework\Filter\Filterable;
use Org\Mxchange\CoreFramework\Request\Requestable;
use Org\Mxchange\CoreFramework\Response\Responseable;

/**
 * A bootstrap InitDaemon filter for daemon
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2015, 2016 City Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class CityDaemonBootstrapInitDaemonFilter extends BaseCityFilter implements Filterable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this filter class
	 *
	 * @return	$filterInstance		An instance of this filter class
	 */
	public final static function createCityDaemonBootstrapInitDaemonFilter () {
		// Get a new instance
		$filterInstance = new CityDaemonBootstrapInitDaemonFilter();

		// Return the instance
		return $filterInstance;
	}

	/**
	 * Executes the filter with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 * @throws	FilterChainException	If $cityInstance is null (no NullPointerException here)
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// Get city instance
		$cityInstance = CityDaemonFactory::createCityDaemonInstance();

		// Now bootstrap the daemon
		$cityInstance->bootstrapInitCityDaemon();
	}
}
