<?php
// Own namespace
namespace Org\Mxchange\City\Daemon\Filter\Initialization\Tasks;

// Import application-specific stuff
use Org\Mxchange\City\Daemon\Factory\CityDaemonFactory;
use Org\Mxchange\City\Filter\BaseCityFilter;

// Import framework stuff
use Org\Mxchange\CoreFramework\Factory\ObjectFactory;
use Org\Mxchange\CoreFramework\Filter\Filterable;
use Org\Mxchange\CoreFramework\Registry\Registry;
use Org\Mxchange\CoreFramework\Request\Requestable;
use Org\Mxchange\CoreFramework\Response\Responseable;

/**
 * A TaskHandlerInitializer filter for hubs
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2015, 2016 City Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class CityDaemonTaskHandlerInitializerFilter extends BaseCityFilter implements Filterable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this filter class
	 *
	 * @return	$filterInstance		An instance of this filter class
	 */
	public static final function createCityDaemonTaskHandlerInitializerFilter () {
		// Get a new instance
		$filterInstance = new CityDaemonTaskHandlerInitializerFilter();

		// Return the instance
		return $filterInstance;
	}

	/**
	 * Executes the filter with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 * @throws	FilterChainException	If the filter chain needs to be interrupted
	 * @todo	Add more tasks
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// Get city instance
		$cityInstance = CityDaemonFactory::createCityDaemonInstance();

		// Get a new task handler instance
		$handlerInstance = ObjectFactory::createObjectByConfiguredName('task_handler_class');

		// Put the task handler in registry
		Registry::getRegistry()->addInstance('task_handler', $handlerInstance);

		// Prepare a city map expansion task
		$taskInstance = ObjectFactory::createObjectByConfiguredName('city_daemon_map_expander_task_class');

		// Register it
		$handlerInstance->registerTask('map_expander', $taskInstance);

		// Prepare a household growth task
		$taskInstance = ObjectFactory::createObjectByConfiguredName('city_daemon_household_growth_task_class');

		// Register it
		$handlerInstance->registerTask('household_growth', $taskInstance);

		// Prepare a building growth task
		$taskInstance = ObjectFactory::createObjectByConfiguredName('city_daemon_building_growth_task_class');

		// Register it
		$handlerInstance->registerTask('building_growth', $taskInstance);

		/*
		 * Add extra tasks depending on daemon modus.
		 */
		$cityInstance->addExtraTasks($handlerInstance);
	}
}
