<?php
// Own namespace
namespace Org\Mxchange\City\State;

// Import application-specific stuff
use Org\Mxchange\City\State\Init\CityInitState;

// Import framework stuff
use Org\Mxchange\CoreFramework\State\BaseState;

/**
 * A general city state class
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2015, 2016 City Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
abstract class BaseCityState extends BaseState {
	/**
	 * Protected constructor
	 *
	 * @param	$className	Name of the class
	 * @return	void
	 */
	protected function __construct ($className) {
		// Call parent constructor
		parent::__construct($className);
	}

	/**
	 * Validates whether the state is 'active' or throws an exception if
	 * it is every other state.
	 *
	 * @return	void
	 * @throws	UnexpectedStateException	If the state is not 'active'
	 */
	public function validateCityStateIsActive () {
		// Just compare it...
		if (!$this instanceof CityActiveState) {
			// Throw the exception
			throw new UnexpectedStateException($this, self::EXCEPTION_INVALID_STATE);
		} // END - if
	}

	/**
	 * Validates whether the state is 'init' or throws an exception if
	 * it is every other state.
	 *
	 * @return	void
	 * @throws	UnexpectedStateException	If the state is not 'virgin'
	 */
	public function validateCityStateIsInit () {
		// Just compare it...
		if (!$this instanceof CityInitState) {
			// Throw the exception
			throw new UnexpectedStateException($this, self::EXCEPTION_INVALID_STATE);
		} // END - if
	}
}
