<?php
// Own namespace
namespace Org\Mxchange\City\Visitor\Task\Active;

// Import framework stuff
use Org\Mxchange\CoreFramework\Generic\BaseDecorator;
use Org\Mxchange\CoreFramework\Task\Taskable;
use Org\Mxchange\CoreFramework\Visitor\BaseVisitor;
use Org\Mxchange\CoreFramework\Visitor\Decorator\DecoratorVisitor;
use Org\Mxchange\CoreFramework\Visitor\Task\TaskVisitor;

/**
 * An ActiveTask visitor
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2017 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class ActiveTaskVisitor extends BaseVisitor implements TaskVisitor, DecoratorVisitor {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Set visitor mode
		$this->setVisitorMode('task');
	}

	/**
	 * Creates an instance of this class
	 *
	 * @return	$visitorInstance	An instance a Visitorable class
	 */
	public static final function createActiveTaskVisitor () {
		// Get new instance
		$visitorInstance = new ActiveTaskVisitor();

		// Return the prepared instance
		return $visitorInstance;
	}

	/**
	 * Visits the given task instance
	 *
	 * @param	$taskInstance	A Taskable instance
	 * @return	void
	 */
	public function visitTask (Taskable $taskInstance) {
		// Execute the task from this visitor
		//* NOISY-DEBUG: */ self::createDebugInstance(__CLASS__, __LINE__)->debugOutput('ACTIVE-TASK-VISITOR: Visiting task ' . $taskInstance->__toString() . ' - CALLED!');
		$taskInstance->executeTask();
		//* NOISY-DEBUG: */ self::createDebugInstance(__CLASS__, __LINE__)->debugOutput('ACTIVE-TASK-VISITOR: Visiting task ' . $taskInstance->__toString() . ' - EXIT!');
	}

	/**
	 * Visits the given decorator instance
	 *
	 * @param	$decoratorInstance	A decorator instance
	 * @return	void
	 */
	public function visitDecorator (BaseDecorator $decoratorInstance) {
		/*
		 * A decorator itself can never become an active task so this method
		 * remains empty.
		 */
		//* NOISY-DEBUG: */ self::createDebugInstance(__CLASS__, __LINE__)->debugOutput(sprintf('ACTIVE-TASK-VISITOR: decoratorInstance=%s - CALLED!', $decoratorInstance->__toString()));
	}

}
