<?php
// Own namespace
namespace Org\Mxchange\City\Manager\City;

// Import own stuff
use Org\Mxchange\City\Manager\Manageable;

/**
 * An interface city manager
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2015, 2016 City Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface ManageableCity extends Manageable {

	/**
	 * Checks whether the current user has already founded a city
	 *
	 * @return	$isFounded	Whether the current user has already founded a city
	 */
	function isCityAlreadyFounded ();

	/**
	 * Checks whether the given city name is already taken
	 *
	 * @para	$cityName	Name of city
	 * @return	$isTaken	Whether the given city name is already taken
	 */
	function ifCityNameExists ($cityName);

	/**
	 * Founds the first city. A dummy region will also be created
	 *
	 * @return	void
	 */
	function foundFirstCity ();

	/**
	 * Renders the city map and forwards the output to the helper instance.
	 *
	 * @param	$helperInstance		An instance of a HelpableTemplate class
	 * @return	void
	 */
	function renderCityMap (HelpableTemplate $helperInstance);
}
